<?php
/**
 * Implementation of hook_ca_predicate().
 */
function ad_auction_ca_predicate() {
  // Set the node status to published when a payment is received
  // and the balance is less than or equal to 0.
  $configurations['ad_auction_received'] = array(
    '#title' => t('Publish advertisement on full payment'),
    '#description' => t('Only happens when a payment is entered and the balance is <= $0.00.'),
    '#class' => 'payment',
    '#trigger' => 'uc_payment_entered',
    '#status' => 1,
    '#conditions' => array(
      '#operator' => 'AND',
      '#conditions' => array(
        array(
          '#name' => 'uc_payment_condition_order_balance',
          '#title' => t('If the balance is less than or equal to $0.00.'),
          '#argument_map' => array(
            'order' => 'order',
          ),
          '#settings' => array(
            'negate' => FALSE,
            'balance_comparison' => 'less_equal',
          ),
        ),
      ),
    ),
    '#actions' => array(
      array(
        '#name' => 'ad_auction_publish_ad',
        '#title' => t('Publish the advertisement in the purchased ad slot.'),
        '#argument_map' => array(
          'order' => 'order',
        ),
      ),
    ),
  );

  return $configurations;
}
function ad_auction_ca_action() {
  $order_arg = array(
    '#entity' => 'uc_order',
    '#title' => t('Order'),
  );
  $actions['ad_auction_publish_ad'] = array(
    '#title' => t('Publish Advertisement'),
    '#category' => t('Drupal'),
    '#callback' => 'ad_auction_publish_advert',
    '#arguments' => array(
      'order' => $order_arg,
    ),
  );

  return $actions;
}

function ad_auction_publish_advert($order) {
  //drupal_set_message('ad slot purchase '.print_r($order,1));
  //  We publish the selected advertisement into each ad slot purchased and set our default values
  foreach($order->products as $product) {
	$node = node_load($product->nid);
	if($node->type=="ad_slot") {
	  db_query("UPDATE {ad_auction} SET uid=%d WHERE nid=%d", $order->uid, $product->nid);
	  //  An add can appear in more than one channel and an ad might be in a channel at the time of this purchase but that al slot may expire before the new ad slot starts
	  //  If the 
	  $count = db_result(db_query("SELECT COUNT(*) FROM {ad_auction} WHERE ad_nid=%d AND nid=%d", $product->data['advert_nid'], $product->nid));
	  if($count==0) drupal_set_message('ad slot data not found', 'error');
	  if($count>1) drupal_set_message('There is a problem with the script in that ad slots are not stored uniquely', 'error');
	  $ad = db_fetch_object(db_query("SELECT * FROM {ad_auction} WHERE ad_nid=%d AND nid=%d", $product->data['advert_nid'], $product->nid));
	  if(!$ad->chid>0) $ad = db_fetch_object(db_query("SELECT * FROM {ad_auction} WHERE nid=%d", $product->nid));
	  $advert = node_load($product->data['advert_nid']);
	  if($advert->adstatus == "active") {
	    // We add this channel to the ad
	    $advert->channel = array(0 => array('channel-'.$ad->chid => 1));
	  }
	  else {
	    $advert->channel = array(0 => array('channel-'.$ad->chid => 1));
		// When an ad is already active you cannot change the autoactivate date and the status has to be 'approved'
		if($ad->start > time()) $advert->adstatus = 'active';
		else $advert->adstatus = 'approved';
		$advert->autoactivate = $ad->start;
	  }
	  $advert->taxonomy[$ad->group_tid] = taxonomy_get_term($ad->group_tid);
	  //variable_get('ad_auction_ad_expiry_period', '')
	  //$advert->activated = $ad->start;
	  //  We change the autoexpire to fit the new ad slot.  The assumption here is that no slots already exist that have an expiry date beyond that which we are applying here.
	  $advert->autoexpire = $ad->expire;
	  
	  //drupal_set_message('ad slot purchase '.print_r($ad,1));
	  //drupal_set_message('ad slot purchase '.print_r($advert,1));
	  node_save($advert);
	}
  }
  
}